function [N_d,N_gv,N_lv,N_mu] = Duns_Ros_dim_less_nrs(d,mu_l,rho_l,sigma_gl,v_sg,v_sl)
% function [N_d,N_gv,N_lv,N_mu] = Duns_Ros_dim_less_nrs(d,mu_l,rho_l,sigma_gl,v_sg,v_sl)   
%
% Computes the Duns-Ros dimensionless numbers.   
%
% d = inside diameter, m
% mu_l = local liquid viscosity, Pa s
% N_d = pipe diameter number, -
% N_gv = gas velocity number, -
% N_lv = liquid velocity number, -
% N_mu = liquid viscosity number, -
% rho_l = local liquid density, kg/m^3 
% sigma_gl = local gas-liquid interfacial tension, N/m 
% v_sg = superficial gas velocity, m/s
% v_sl = superficial liquid velocity, m/s
%
% JDJ, 30-10-11, last revised 10-05-13
%
% Reference:
% Duns, H. and Ros, N.C.J., 1963: Vertical flow of gas and liquid mixtures in wells. Proc.
% 6th World Petroleum Congress, section II, 451-465, paper 22-PD6. 

% Compute internal variables:
g = 9.81; % acceleration of gravity, m/s^2

% Compute Duns and Ros dimensionless numbers:
N_d  = d*sqrt(g*rho_l/sigma_gl);% pipe diameter number, -
N_gv = abs(v_sg)*(rho_l/(g*sigma_gl))^(1/4); % gas velocity number, -
N_lv = abs(v_sl)*(rho_l/(g*sigma_gl))^(1/4); % liquid velocity number, -
N_mu = mu_l*(g/(rho_l*sigma_gl^3))^(1/4); % liquid viscosity number, -

