% Script file answer_question_5_14
%
% JDJ, 23-10-13, last revised 07-12-16

clear variables
close all

% Input data:
alpha_t = from_deg_to_rad(0); % wellbore inclination , rad
alpha_fl = from_deg_to_rad(90); % flow line inclination , rad
C_d = 0.9; % choke discharge coefficient, -
c_l = 0.82; % specific heat capacity of liquid at constant volume, J/(kg K)
c_p = 0.26; % specific heat capacity of gas at constant pressure, J/(kg K)
c_v = 0.20; % specific heat capacity of gas at constant volume, J/(kg K)
d_ch = 0.0127; % choke diameter, m
d_t = 0.07; % tubing inside diameter, m
d_fl = 0.10; % flow line inside diameter, m
e_t = 30e-6; % tubing roughness, m
e_fl = 30e-6; % flow line roughness, m
f_w_sc = 0.7; % = q_w_sc/(q_w_sc+q_o_sc) = water cut, -
fluid = 4; % multi-phase gas-oil-water flow, Mukherjee and Brill correlation
oil = 1; % black oil; parameters computed with the aid of Standing correlations
n_pt = 50; % number of points in plot, - 
p_mf = 1.2e6; % manifold pressure, Pa
q_o_sc_max = -150/(24*3600); % maximum oil rate, m^3/s
R_go = 40; % producing GOR as observed at surface, m^3/m^3
rho_g_sc = 0.87; % gas density at standard conditions, kg/m^3 
rho_o_sc = 865;  % oil density at standard conditions, kg/m^3
rho_w_sc = 1030; % water density at standard conditions, kg/m^3
T_mf = 40; % manifold temperature, deg. C
T_wf = 110; % bottomhole temperature, deg. C
L_t = 3300; % tubing length (well depth), m
L_fl = 1800; % flow line length, m

% Compute auxiliary variables:
L_tot = L_fl + L_t; % total system length, m 
Delta_T = T_wf - T_mf; % total temperature drop, deg. C
T_fl = T_mf - Delta_T*L_fl/L_tot; % flow line temperature (downstream from choke), deg. C
T_tf = T_fl; % FTHT (neglecting temperature drop over choke), deg. C

% Create data vector:
rho_sc = [rho_g_sc,rho_o_sc,rho_w_sc];

% Compute pressure drop at increasing rates:
delta_q_o_sc = q_o_sc_max/n_pt; % oil rate increment, m^3/s
results = zeros(n_pt,5);
for i=1:n_pt
    q_o_sc = i * delta_q_o_sc % oil rate, m^3/s
    q_g_sc = R_go * q_o_sc; % gas rate, m^3/s
    q_w_sc = (f_w_sc/(1-f_w_sc)) * q_o_sc; % water rate, m^3/s
    q_sc = [q_g_sc,q_o_sc,q_w_sc];
    p_fl = pipe(alpha_fl,d_fl,e_fl,fluid,oil,p_mf,q_sc,rho_sc,0,L_fl,T_mf,T_fl);
    [p_tf,r_crit] = choke_multi_phase(C_d,c_l,c_p,c_v,d_ch,oil,p_fl,q_sc,rho_sc,T_tf);
    r_act = p_fl/p_tf;
    p_wf = pipe(alpha_t,d_t,e_t,fluid,oil,p_tf,q_sc,rho_sc,L_fl,L_tot,T_tf,T_wf);
    results(i,1:5) = [-q_o_sc p_tf p_wf r_crit r_act];
end

% Create simple plots:
plot(results(:,1)*1e3,results(:,2)/1e6,'LineWidth',1)
xlabel('Oil Flowrate,\it -q_{o,sc}\rm (10^{-3} m^3/s)')
ylabel('FTHP,\it p_{tf}\rm (MPa)')
grid on

figure
plot(results(:,1)*1e3,results(:,3)/1e6,'LineWidth',1)
xlabel('Oil Flowrate,\it -q_{o,sc}\rm (10^{-3} m^3/s)')
ylabel('FBHP,\it p_{wf}\rm (MPa)')
grid on

figure
plot(results(:,1)*1e3,results(:,4:5),'LineWidth',1)
xlabel('Oil Flowrate,\it -q_{o,sc} ,\rm (10^{-3} m^3/s)')
ylabel('Pressure Ratio,\it r = p_{fl} /p_{tf}\rm (-)')
legend('\itr_{\rmcrit}','\itr_{\rmact}')
grid on
