% Script file answer_question_6_14
%
% Iteratively computes the CBHP of a gas well with two cross-flowing layers. 
%
% JDJ, 29-12-13, last revised 08-01-16

clear variables
close all

% ---------------------------------------------------------------------------------------------
% Input data:
% ---------------------------------------------------------------------------------------------
beta = 4.0e10; % Forchheimer coefficient, 1/m
fluid = 2; % single-phase gas flow, -
h = 20.0; % reservoir height, m
k_1 = 1.e-14; % effective permeability upper layer, m^2
k_2 = 0.5e-14; % effective permeability lower layer, m^2
n_pt = 500; % number of points in plot, - 
oil = 1; % arbitrary value; not relevant, but required by res.m
p_R_1 = 9.0e6; % upper layer reservoir pressure, Pa
p_R_2 = 10e6; % lower layer reservoir pressure, Pa
r_e = 400; % external radius, m
r_w = 0.2; % well bore radius, m
rho_g_sc = 0.93; % gas density at standard conditions, kg/m^3
rho_o_sc = 0; % arbitrary value; not relevant, but required by res.m
rho_w_sc = 0; % arbitrary value; not relevant, but required by res.m
T_R = 80; % reservoir temperature, deg. C
% ---------------------------------------------------------------------------------------------
% End of input data
% ---------------------------------------------------------------------------------------------

% Create data vectors:
rel = [0,0,0,0,0,0,0,0,0,0]; % arbitrary values; not relevant, but required by res.m  
rho_sc = [rho_g_sc,rho_o_sc,rho_w_sc];

% Specify the initial guess:
start = 0.5; % initial guess for gas flow rate, m^3/s 

% Compute the cross-flow rate:
q_g_sc = fzero(@(q_g_sc)...
    res(beta,fluid,h,k_1,oil,p_R_1,[ q_g_sc,0,0],r_e,r_w,rel,rho_sc,T_R) - ...
    res(beta,fluid,h,k_2,oil,p_R_2,[-q_g_sc,0,0],r_e,r_w,rel,rho_sc,T_R),start)

% Compute the corresponding CBHP (= p_wf_1 = p_wf_2):
p_wc = res(beta,fluid,h,k_1,oil,p_R_1,[q_g_sc,0,0],r_e,r_w,rel,rho_sc,T_R)

% Compute the flow rate for a FBHP of 6 MPa:
p_wf = 6e6; % FBHP, Pa
lo = -2.5; % lower bound for flow rate, m^3/s
hi =  0; % upper bound for flow rate, m^3/s
% Note: specifying upper and lower bounds is an optional alternative to specifying a starting
%       value. This particular choice avoids the computation of negative pressures.
q_g_sc_1 = fzero(@(q_g_sc_1)...
    p_wf - res(beta,fluid,h,k_1,oil,p_R_1,[q_g_sc_1,0,0],r_e,r_w,rel,rho_sc,T_R), [lo hi]);
lo = -2.0; % lower bound for flow rate, m^3/s
hi =  0; % upper bound for flow rate, m^3/s
q_g_sc_2 = fzero(@(q_g_sc_2)...
    p_wf - res(beta,fluid,h,k_2,oil,p_R_2,[q_g_sc_2,0,0],r_e,r_w,rel,rho_sc,T_R), [lo hi]);
q_g_sc = q_g_sc_1 + q_g_sc_2
