function k_ro = Stone_II(k_r,rel)
% function k_ro = Stone_II(k_r,rel)
%
% Computes the relative permeability to oil with the aid of the modified Stone II
% approximation. 
%
% JDJ, 18-02-15, last revised 18-02-15
%
% k_r = [k_rg,k_rog,k_row,k_rw];
%   k_rg = relative permeability to gas, -
%   k_rog = relative permeability to oil in gas-oil flow, -
%   k_row = relative permeability to oil in oil-water flow, -
%   k_rw = relative permeability to water, -
% rel = [k_rg_0,k_ro_0,k_rw_0,n_g,n_og,n_ow,n_w,S_gc,S_or,S_wc]
%   k_rg_0 = end-point relative permeability to gas, -
%   k_ro_0 = end-point relative permeability to oil, -
%   k_rw_0 = end-point relative permeability to water, -
%   n_g = Corey exponent for gas, -
%   n_og = Corey exponent for oil in gas-oil flow, -
%   n_ow = Corey exponent for oil in oil-water flow, -
%   n_w = Corey exponent for water, -
%   p_av = average reservoir pressure, Pa
%   S_gc = critical gas saturation, -
%   S_or = residual oil saturation, -
%   S_wi = immobile water saturation, -

% Retrieve data:
k_rg = k_r(1);
k_rog = k_r(2);
k_row = k_r(3);
k_rw = k_r(4);
k_ro_0 = rel(2);

% Compute k_ro:
k_ro = k_ro_0*((k_rog/k_ro_0+k_rg)*(k_row/k_ro_0+k_rw))-(k_rg+k_rw); % modified Stone II
if k_ro < 0
    k_ro = eps;
end
