% script file example_gas_pseu_pres
%
% Computes and plots the real gas pseudo pressure as a function of pressure. Creates a table
% (i.e. two vectors, p and m) which can be used to compute the pseudo pressure m(p) using
% interpolation: m_i = interp1(p,m,p_i), where p_i is a given pressure and m_i the
% corresponding (to be computed) pseudo pressure. 
%
% JDJ, 11-04-11, last revised 29-05-17

clear variables
close all

% ---------------------------------------------------------------------------------------------
% Input data:
% ---------------------------------------------------------------------------------------------
p_max = 30e6; % maximum pressure (upper limit integration), Pa 
p_ref = 0.1e6; % reference pressure (lower limit integration), Pa
rho_g_sc = 0.95; % gas density at standard conditions, kg/m^3 
T = 75; % temperature, deg. C
% ---------------------------------------------------------------------------------------------
% End of input data
% ---------------------------------------------------------------------------------------------

% Compute table:
[p m] = gas_pseu_pres(p_max,p_ref,rho_g_sc,T);

% Example to compute a pseudo pressure through interpolation:
p_i = 15e6 % arbitraryly chosen pressure between reference pressure and maximum pressure, Pa
m_i = interp1(p,m,p_i) % corresponding pseudo pressure, Pa

% Plot:
plot(p/1e6,m/1e6,'LineWidth',1)
xlabel('Pressure,\it p\rm (MPa)')
ylabel('Pseudo Pressure,\it m\rm (MPa)')
grid on
