function dmdp = gas_dmdp(p,~,~,C,rho_g_sc,T)
% function dmdp = gas_dmdp(p,~,~,C,rho_g_sc,T)
%
% Auxiliary function for gas_pseu_pres.m to compute real gas pseudo pressures. This function
% can be used to compute the pseudo pressure through numerical integration. It has the correct
% format to be used with one of the standard numerical integration routines in MATLAB.
%
% See also: example_gas_pseu_pres.m
%
% C = constant, s
% p = pressure, Pa
% rho_g_sc = gas density at standard conditions, kg/m^3 
% T = temperature, deg. C
%
% JDJ, 11-04-11, last revised 12-04-11

T_abs = T + 273.15;
mu_g = gas_viscosity(p,rho_g_sc,T);
p_pc = pres_pseu_crit_Sutton(rho_g_sc);
T_pc = temp_pseu_crit_Sutton(rho_g_sc);
p_pr = p/p_pc;
T_pr = T_abs/T_pc;
Z = Z_factor_DAK(p_pr,T_pr);
dmdp = C * p / (mu_g * Z);

