function [p m] = gas_pseu_pres(p_max,p_ref,rho_g_sc,T)
% function [p m] = gas_pseu_pres(p_max,p_ref,rho_g_sc,T)
%
% Computes real gas pseudo pressures trough numerical integration.
%
% See also: example_gas_pseu_pres.m
%
% m = vector of pseudo pressures, Pa
% p = vector of pressures, Pa
% p_max = maximum pressure (upper limit integration), Pa 
% p_ref = reference pressure (lower limit integration), Pa
% rho_g_sc = gas density at standard conditions, kg/m^3 
% T = temperature, deg. C
%
% JDJ, 11-04-11, last revised 10-05-13

% Compute constant factor C:
T_abs = T + 273.15;
mu_g = gas_viscosity(p_ref,rho_g_sc,T);
p_pc = pres_pseu_crit_Sutton(rho_g_sc);
T_pc = temp_pseu_crit_Sutton(rho_g_sc);
p_pr = p_ref/p_pc;
T_pr = T_abs/T_pc;
Z = Z_factor_DAK(p_pr,T_pr);
C = mu_g * Z / p_ref;

% Integrate:
interval = [p_ref p_max];
boundcon = p_ref;
options = [];
[p,m] = ode45('gas_dmdp',interval,boundcon,options,C,rho_g_sc,T);
