function plot_survey(nor,eas,tvd)
% function plot_survey(nor,eas,tvd)
%
% Creates various plots to visualise well bore survey data.
%
% nor = northing (m)
% eas = easting (m)
% tvd = true-vertical depth (m)
%
% JDJ, 19-08-04, last revised 29-05-17

% Plot 1 consists of 4 sub plots which have been oriented such that in the top view (E-W view),
% North points to the top of the paper. This implies that in the top view the x-axis (N-S) runs
% vertical, while the y-axis (E-W) runs horizontal. 

x = nor;
y = eas;
z = tvd;

x_min = min(x);
x_max = max(x);
y_min = min(y);
y_max = max(y);
z_min = min(z);
z_max = max(z);

x_len = x_max - x_min;
y_len = y_max - y_min;
z_len = z_max - z_min;

border = 0.05 * max([x_len y_len z_len]);

x_min_plot = x_min - border;
x_max_plot = x_max + border;
y_min_plot = y_min - border;
y_max_plot = y_max + border;
z_min_plot = z_min - border;
z_max_plot = z_max + border;

x_len_plot = x_max_plot - x_min_plot;
y_len_plot = y_max_plot - y_min_plot; 
z_len_plot = z_max_plot - z_min_plot; 

xxz_frac_plot = x_len_plot / (x_len_plot + z_len_plot); 
yyz_frac_plot = y_len_plot / (y_len_plot + z_len_plot); 
zxz_frac_plot = z_len_plot / (x_len_plot + z_len_plot);
zyz_frac_plot = z_len_plot / (y_len_plot + z_len_plot); 

% Compute (relative) subplot positions (left, bottom, width, height). (Note: all relative
% posititions are with respect to the bottom-left corner of the main plot): 
txt_brdr_hor = 0.2; % horizontal border for axes text etc. (relative to main plot size), - 
txt_brdr_ver = 0.1; % vertical border for axes text etc. (relative to main plot size), - 
space_hor = (1 - 2.5 * txt_brdr_hor); % horizontal space left for plots, - 
space_ver = (1 - 2.5 * txt_brdr_ver); % vertical space left for plots, - 

width_tl = yyz_frac_plot * space_hor; % width of top-left subplot, - 
height_tl = xxz_frac_plot * space_ver; % heigth of top-left subplot, - 
width_tr = zyz_frac_plot * space_hor; % width of top-right subplot, - 
height_tr = xxz_frac_plot * space_ver; % heigth of top-right subplot, - 
width_bl = yyz_frac_plot * space_hor; % width of bottom-left subplot, - 
height_bl = zxz_frac_plot * space_ver; % heigth of bottom-left subplot, - 
width_br = zyz_frac_plot * space_hor; % width of bottom-right subplot, - 
height_br = zxz_frac_plot * space_ver; % heigth of bottom-right subplot, - 

left_tl = txt_brdr_hor; % left boundary of top-left subplot, - 
bottom_tl = 2 * txt_brdr_ver + height_bl; % bottom boundary of top-left subplot, - 
left_tr = 2 * txt_brdr_hor + width_tl; % left boundary of top-right subplot, - 
%left_tr = 1 * txt_brdr_hor + width_tl; % left boundary of top-right subplot, - 
bottom_tr = 2 * txt_brdr_ver + height_br; % bottom boundary of top-right subplot, - 
left_bl = txt_brdr_hor; % left boundary of bottom-left subplot, - 
bottom_bl = txt_brdr_ver; % bottom boundary of bottom-left subplot, - 
left_br = 2 * txt_brdr_hor + width_bl; % left boundary of bottom-right subplot, - 
%left_br = 1 * txt_brdr_hor + width_bl; % left boundary of bottom-right subplot, - 
bottom_br = txt_brdr_ver; % bottom boundary of bottom-right subplot, - 

% Data to display coordinates axes in plots:
x_line = [  x_min_plot   0        0       ;    ...
            x_max_plot   0        0       ]; 
y_line = [      0    y_min_plot   0       ;    ...
                0    y_max_plot   0       ];
z_line = [      0        0    z_min_plot  ;    ...
                0        0    z_max_plot  ];

subplot('Position',[left_tl bottom_tl width_tl height_tl]) % top-left subplot; N-E (top) view
hold on
plot(y,x,'LineWidth',1.5);
plot(x_line(:,2),x_line(:,1),'Color','k','LineWidth',0.5);
plot(y_line(:,2),y_line(:,1),'Color','k','LineWidth',0.5);
hold off
axis([y_min_plot,y_max_plot,x_min_plot,x_max_plot])
daspect([1 1 1])
xlabel('easting,\it y\rm (m)')
ylabel('northing,\it x\rm (m)')
grid on
box on

subplot('Position',[left_tr bottom_tr width_tr height_tr]) % top-right subplot; N-TVD view
hold on
plot(z,x,'LineWidth',1.5);
plot(x_line(:,3),x_line(:,1),'Color','k','LineWidth',0.5);
plot(z_line(:,3),z_line(:,1),'Color','k','LineWidth',0.5);
hold off
axis([z_min_plot,z_max_plot,x_min_plot,x_max_plot])
daspect([1 1 1])
xlabel('TVD,\it z\rm (m)')
ylabel('northing,\it x\rm (m)')
grid on
box on

subplot('Position',[left_bl bottom_bl width_bl height_bl]) % bottom-left subplot; E-TVD view
hold on
plot(y,z,'LineWidth',1.5);
plot(y_line(:,2),y_line(:,3),'Color','k','LineWidth',0.5);
plot(z_line(:,2),z_line(:,3),'Color','k','LineWidth',0.5);
hold off
axis([y_min_plot,y_max_plot,z_min_plot,z_max_plot])
axis ij
daspect([1 1 1])
xlabel('easting,\it y\rm (m)')
ylabel('TVD,\it z\rm (m)')
grid on
box on

subplot('Position',[left_br bottom_br width_br height_br]) % bottom-right subplot; 3D view
plot3(y,x,z,'LineWidth',1.5);
daspect([1 1 1])
set(gca,'ZDir','reverse')
xlabel('easting,\it y\rm (m)')
ylabel('northing,\it x\rm (m)')
zlabel('TVD,\it z\rm (m)')
grid on
box on

% Plot 2 ('curtain plot'):
figure
x = nor;
y = eas;
n = length(x);
s_hor = zeros(n,1);
s_hor(1) = 0;
for i=2:n
    delta_x = x(i)-x(i-1);
    delta_y = y(i)-y(i-1);
    delta_s_hor = sqrt(delta_x^2+delta_y^2); 
    s_hor(i) = s_hor(i-1) + delta_s_hor;  % approximate projected AHD, m
end
    
line(s_hor,tvd,'LineWidth',1)
axis ij
grid on
box on
xlabel('Projected AHD,\it s_{\rmhor}\rm (m)')
ylabel('TVD,\it z\rm (m)')

